<?php
if(!defined("ABSPATH")) {
    exit;
}

add_action("wp_ajax_send_cuk_quote", array("CUKAjaxCallbacks", "sendQuote"));
add_action("wp_ajax_nopriv_send_cuk_quote", array("CUKAjaxCallbacks", "sendQuote"));

if(!class_exists("CUKAjaxCallbacks")) {
    class CUKAjaxCallbacks {
        // Send quote via email
        public static function sendQuote() {
            if(! check_ajax_referer("^c0nv3yUKAjaxK3y$", "security", false)) {
                wp_send_json_error("Invalid nonce");
            } else {
                $adminEmail = get_option("cuk_additional_inputs")["cuk_admin_email_recepient"];
                $to = sanitize_email($_POST["recepient"]);
                $fromSiteName = get_bloginfo("name");
                $fromEmail = $adminEmail;
                $subject = "Conveyancing quote";
                $headers[] = "From: {$fromSiteName} <{$fromEmail}>";
                $headers[] = "Cc: {$adminEmail}";
                $headers[] = "Content-Type: text/html; charset=UTF-8";

                $resultsStr = "";
                foreach($_POST["selectedTables"] as $table) {
                    $resultsStr .= "<table style='margin-top: 20px;width:100%;'>";
                    $resultsStr .= "<tr><td colspan='2' style='font-weight:bold;font-size:20px;padding-top:10px;padding-bottom:10px;'>{$table['title']}</td></tr>";
                    foreach($table["fields"] as $key => $val) {
                        $title_styles = "";
                        if(strtolower($key) === "expenses" || strtolower($key) === "fees") {
                            $title_styles = "style='font-weight:bold;font-size:18px;background-color:#dadada;'";
                        }
                        $totals_styles = "";
                        if(strtolower($key) === "expenses total" || strtolower($key) === "fees total" || strtolower($key) === "grand total") {
                            $totals_styles = "style='text-align:right;font-weight:bold;font-size:18px;background-color:#727272;color:white;'";
                        }
                        $numerical_value_styles = "style='text-align:right;'";
                        if(strtolower($key) === "expenses total" || strtolower($key) === "fees total" || strtolower($key) === "grand total") {
                            $numerical_value_styles = "style='text-align:right;background-color:#727272;color:white;'";
                        }

                        $resultsStr .= "<tr>";
                            $resultsStr .= "<td {$title_styles} {$totals_styles}>{$key}</td>";
                            $resultsStr .= "<td {$title_styles} {$numerical_value_styles}>{$val}</td>";
                        $resultsStr .= "</tr>";
                    }
                    $resultsStr .= "</table>";
                }
                
                date_default_timezone_set('Europe/London');
                $emailVars = array(
                    "[{RESULTS}]" => $resultsStr,
                    "[{DISCLAIMER}]" => get_option("cuk_additional_inputs", "")["cuk_disclaimer_statement"],
                    "[{RECEPIENT}]" => $to,
                    "[{DATE}]" => date("d-m-Y H:i:s A"),
                );

                $searches_and_vat_approx_text = get_option("cuk_expense_fees", "")["cuk_searches_expense_description"];
                
                $searchesAndVATApprox = "";
                foreach($_POST["selectedTables"] as $table) {
                    if(strpos(strtolower($table["title"]), "purchase") !== false) { // If a purchase table is found then add to the emailVars array
                        $searchesAndVATApprox = "<tr><td style='text-align:center;'><h3>* Searches and VAT (approx)</h3></td></tr>";
                        $searchesAndVATApprox .= "<tr><td style='text-align:center; margin-top: 10px;'><div><p>{$searches_and_vat_approx_text}</p></div></td></tr><hr/>";
                    }
                }
                $emailVars["[{SEARCHESANDVATAPPROX}]"] = $searchesAndVATApprox;

                $message = file_get_contents(__DIR__."/mail.tpl");
                $message = strtr($message, $emailVars);                

                $mailResult = wp_mail($to, $subject, $message, $headers);
                if($mailResult) {
                    wp_send_json_success("Mail sent successfully to {$to}");
                } else {
                    wp_send_json_error("Mail could not be sent to {$to}", 500);
                }
            }
        }
    }
}