<?php
if(! class_exists("CUK_Database")) {
    class CUK_Database {

        // Fetch plugin info
        public static function cuk_fetch_plugin_info() {
            return get_option("cuk_plugin_info");
        }

        // Fetch options for the saved expenses
        public static function cuk_fetch_expensefee_options() {
            return get_option("cuk_expense_fees");
        }

        // Fetch options for the saved legal fees
        public static function cuk_fetch_fee_options() {
            return get_option("cuk_fees");
        }
        
        // Fetch options for the saved legal fees
        public static function cuk_fetch_additional_inputs() {
            return get_option("cuk_additional_inputs");
        }

        // Set options for expenses
        public static function cuk_save_expense_options($options) {
            $expenses_r = array(
                "cuk_freehold_sale_title_and_plan_copy" => sanitize_text_field( $options["cuk-freehold-sale-title-and-plan-copy"] ),
                "cuk_freehold_sale_documents_copy" => sanitize_text_field( $options["cuk-freehold-sale-documents-copy"] ),
                "cuk_leasehold_sale_title_and_plan_copy" => sanitize_text_field( $options["cuk-leasehold-sale-title-and-plan-copy"] ),
                "cuk_leasehold_sale_freehold_title_and_plan_copy" => sanitize_text_field( $options["cuk-leasehold-sale-freehold-title-and-plan-copy"] ),
                "cuk_leasehold_sale_documents_copy" => sanitize_text_field( $options["cuk-leasehold-sale-documents-copy"] ),
                "cuk_leasehold_sale_managing_agents_fees" => sanitize_text_field( $options["cuk-leasehold-sale-managing-agents-fees"] ),
                "cuk_freehold_purchase_searches_and_vat" => sanitize_text_field( $options["cuk-freehold-purchase-searches-and-vat"] ),
                "cuk_freehold_purchase_land_reg_fee" => sanitize_text_field( $options["cuk-freehold-purchase-land-reg-fee"] ),
                "cuk_freehold_purchase_bankruptcy" => sanitize_text_field( $options["cuk-freehold-purchase-bankruptcy"] ),
                "cuk_leasehold_purchase_searches_and_vat" => sanitize_text_field( $options["cuk-leasehold-purchase-searches-and-vat"] ),
                "cuk_leasehold_purchase_land_reg_fee" => sanitize_text_field( $options["cuk-leasehold-purchase-land-reg-fee"] ),
                "cuk_leasehold_purchase_bankruptcy" => sanitize_text_field( $options["cuk-leasehold-purchase-bankruptcy"] ),
                "cuk_leasehold_purchase_transfer_notice_charge" => sanitize_text_field( $options["cuk-leasehold-purchase-transfer-notice-charge"] ),
                "cuk_searches_expense_description" => sanitize_text_field( $options["cuk-searches-expense-description"] )
            );

            update_option("cuk_expense_fees", $expenses_r); // We are updating since these values were already created on plugin installation
        }
        
        // Set options for legal fees
        public static function cuk_save_fee_options($options) {
            // Save values as options
            $fees_r = array(
                "cuk_sameday_bank_transfer" => sanitize_text_field( $options["cuk-sameday-bank-transfer"] ),
                "cuk_filestorage_fee" => sanitize_text_field( $options["cuk-filestorage-fee"] ),
                "cuk_legal_freeholdstartPrice" => sanitize_text_field( $options["cuk-freeholdstartPrice"] ),
                "cuk_legal_leaseholdstartPrice" => sanitize_text_field( $options["cuk-leaseholdstartPrice"] ),
                "cuk_legal_freeholdBasicFee" => sanitize_text_field( $options["cuk-freeholdBasicFee"] ),
                "cuk_legal_leaseholdBasicFee" => sanitize_text_field( $options["cuk-leaseholdBasicFee"] ),
                "cuk_legal_freeholdpriceIncrease" => sanitize_text_field( $options["cuk-freeholdpriceIncrease"] ),
                "cuk_legal_leaseholdpriceIncrease" => sanitize_text_field( $options["cuk-leaseholdpriceIncrease"] ),
                "cuk_legal_freeholdfeeIncrease" => sanitize_text_field( $options["cuk-freeholdfeeIncrease"] ),
                "cuk_legal_leaseholdfeeIncrease" => sanitize_text_field( $options["cuk-leaseholdfeeIncrease"] ),
            );

            update_option("cuk_fees", $fees_r); // We are updating since these values were already created on plugin installation
        }

        // Set options for legal fees
        public static function cuk_save_additional_inputs($options) {
            // Save values as options
            $additional_info_r = array(
                "cuk_admin_email_recepient" => sanitize_email($options["cuk-admin-email"]),
                "cuk_disclaimer_statement" => wp_kses($options["cuk-disclaimer"], "post"),
                "cuk_gdpr_statement" => wp_kses($options["cuk-GDPR"], "post")
            );

            update_option("cuk_additional_inputs", $additional_info_r); // We are updating since these values were already created on plugin installation
        }
        
        // Set plugin info
        public static function cuk_save_license_key($options) {
            // Check if license key is valid
            $license_key = sanitize_text_field( $options["cuk-license-key"] );
            
            $api_params = array(
                "slm_action" => "slm_activate",
                "secret_key" => "62d171f35a1a98.85170837",
                "license_key" => $license_key,
                "registered_domain" => $_SERVER["SERVER_NAME"],
                "item_reference" => urlencode("conveyUK plugin for " . get_bloginfo("name"))
            );

            // Send query to license manager server
            $query = esc_url_raw(add_query_arg($api_params, "https://conveyuk.com"));
            $response = wp_remote_get($query, array("timeout" => 20, "sslverify" => false));

            // Check for error
            if(is_wp_error($response)) {
                new CUK_Admin_Message("error", "REMOTE ERROR: An unexpected error occured");
            }

            // License data
            $license_data = json_decode(wp_remote_retrieve_body($response));

            if($license_data->result == "success") {
                // Save values as options
                $set_plugin_info = get_option("cuk_plugin_info");
                
                $set_plugin_info["cuk_license_key"] = $license_key;
                $set_plugin_info["cuk_license_status"] = "active";

                update_option("cuk_plugin_info", $set_plugin_info);

                new CUK_Admin_Message("success", "SUCCESS: ".$license_data->message);
            } else {
                new CUK_Admin_Message("error", "REMOTE RESPONSE: ".$license_data->message);
            }
        }
        
        // Check license key
        public static function check_license_key($options) {
            $plugin_info = get_option("cuk_plugin_info");
            $license_key = $plugin_info["cuk_license_key"];
            $license_key_status = $plugin_info["cuk_license_status"];

            if(strlen($license_key) <= 0) {
                return; // There is no license key to check
            }

            $api_params = array(
                "slm_action" => "slm_check",
                "secret_key" => "62d171f35a1a98.85170837",
                "license_key" => $license_key,
            );

            // Send query to license manager server
            $query = esc_url_raw(add_query_arg($api_params, "https://conveyuk.com"));
            $response = wp_remote_get($query, array("timeout" => 20, "sslverify" => false));

            // Check for error
            if(is_wp_error($response)) {
                new CUK_Admin_Message("error", "REMOTE ERROR: An unexpected error occured");
            }

            // License data
            $license_data = json_decode(wp_remote_retrieve_body($response));

            if($license_data->result == "success") {
                if(strlen($license_expiry) <= 0) $plugin_info["cuk_expires"] = $license_data->date_expiry; // If we did have this before

                $plugin_info["cuk_license_status"] = $license_data->status;

                update_option("cuk_plugin_info", $plugin_info);
            } else {
                // An error was encountered
                new CUK_Admin_Message("error", "ERROR: ".$license_data->message);

                $plugin_info["cuk_expires"] = "";
                $plugin_info["cuk_license_status"] = "inactive";

                update_option("cuk_plugin_info", $plugin_info);
            }

        }
    }
}
add_action("wp_login", array("CUK_Database", "check_license_key")); // Check the remote server license status on admin login


// Fetch options from DB
$cuk_fees_options = CUK_Database::cuk_fetch_fee_options();
$cuk_expensefees_options = CUK_Database::cuk_fetch_expensefee_options();
$cuk_additional_inputs = CUK_Database::cuk_fetch_additional_inputs();
$cuk_plugin_info = CUK_Database::cuk_fetch_plugin_info();

add_action("init", "cuk_fetch_all_data");
function cuk_fetch_all_data() {
    global $cuk_fees_options;
    global $cuk_expensefees_options;
    global $cuk_additional_inputs;
    global $cuk_plugin_info;

    $cuk_fees_options = CUK_Database::cuk_fetch_fee_options();
    $cuk_expensefees_options = CUK_Database::cuk_fetch_expensefee_options();
    $cuk_additional_inputs = CUK_Database::cuk_fetch_additional_inputs();
    $cuk_plugin_info = CUK_Database::cuk_fetch_plugin_info();
}