jQuery(document).ready(function ($) {
  // last updated 20/07/2022

  let tables = [
    {
      selected: false,
      title: "Freehold purchase",
      fields: {
        Expenses: "",
        "Searches and VAT (approx)*": 0,
        "Stamp Duty Land Tax ( Standard SDLT )": 0,
        "Land Registry Registration Fee": 0,
        "Land Registry Search Fee": 0,
        "Land Charges (Bankruptcy) Search Fee (per name)": 0,
        "Expenses total": 0,
        Fees: "",
        "Legal fees": 0,
        "Fee for each same day bank transfer": 0,
        "File storage fee": 0,
        "VAT at 20.0%": 0,
        "Fees total": 0,
        "Grand Total": 0,
      },
    },
    {
      selected: false,
      title: "Freehold sale",
      fields: {
        Expenses: "",
        "Official Copy of title and plan": 0,
        "Official Copy Documents (if necessary)": 0,
        "Expenses total": 0,
        Fees: "",
        "Legal fees": 0,
        "Fee for each same day bank transfer": 0,
        "File storage fee": 0,
        "VAT at 20.0%": 0,
        "Fees total": 0,
        "Grand Total": 0,
      },
    },
    {
      selected: false,
      title: "Leasehold purchase",
      fields: {
        Expenses: "",
        "Searches and VAT (approx)*": 0,
        "Stamp Duty Land Tax ( Standard SDLT )": 0,
        "Land Registry Registration Fee": 0,
        "Notice to Freeholder/Landlord of Transfer & Charge (approximate)":
          undefined,
        "Land Registry Search Fee": 0,
        "Land Charges (Bankruptcy) Search Fee (per name)": 0,
        "Expenses total": 0,
        Fees: "",
        "Legal fees": 0,
        "Fee for each same day bank transfer": 0,
        "File storage fee": 0,
        "VAT at 20.0%": 0,
        "Fees total": 0,
        "Grand Total": 0,
      },
    },
    {
      selected: false,
      title: "Leasehold sale",
      fields: {
        Expenses: "",
        "Official Copy of title and plan (leasehold)": 0,
        "Official Copy of title and plan (freehold)": 0,
        "Official Copy Documents": 0,
        "Managing Agent's Fees (replies to enquiries) (inc. VAT) (approx.)":
          undefined,
        "Expenses total": 0,
        Fees: "",
        "Legal fees": 0,
        "Fee for each same day bank transfer": 0,
        "File storage fee": 0,
        "VAT at 20.0%": 0,
        "Fees total": 0,
        "Grand Total": 0,
      },
    },
  ];

  // Check if we have a wide enough space to display as grid
  if ($(".cuk-plugin-wrapper").width() <= 768) {
    $(".cuk-plugin-wrapper").addClass("cuk-display-stacked");
  }

  // If we change any value then hide the results
  $("#CUK-calculator-form input").each(function () {
    $(this).change(function () {
      resetResultsFields();
    });
  });

  // BUYING
  // If the buying checkbox is clicked show the buying options
  let selectedSDLT = "sdltftb";

  $("[name='buying']").click(function () {
    if (this.checked) {
      $(".cuk-buying-options").addClass("cuk-selected");
      $(".cuk-buying-options").removeClass("cuk-unselected");
    } else {
      $(".cuk-buying-options").removeClass("cuk-selected");
      $(".cuk-buying-options").addClass("cuk-unselected");
      $("[name='purchaseTenure']").prop("checked", false); // Reset if freehold/leasehold had been selected
      $("[name='sdltRate']").prop("checked", false); // Reset if sdlt had been selected
      $("[name='purchasePrice']").val(""); // Reset purchase price
    }
  });

  $("[name='purchaseTenure']").change(function () {
    $(".cuk-sdlt-options").addClass("cuk-show");
  });

  $("[name='sdltRate']").change(function () {
    $(".cuk-purchaseprice-input").addClass("cuk-show");
    selectedSDLT = $(this).val();

    switch (
      selectedSDLT // Show which SDLT rate was chosen
    ) {
      case "sdlt":
        $(".cuk-selected-sdlt").text(" ( Standard SDLT ) ");
        break;
      case "sdltftb":
        $(".cuk-selected-sdlt").text(" ( First-Time Buyer SDLT ) ");
        break;
      case "sdlthr":
        $(".cuk-selected-sdlt").text(" ( Higher-Rate SDLT ) ");
        break;
      default:
        $(".cuk-selected-sdlt").text("");
        break;
    }

    populateResultsFields();
  });

  // SELLING
  // If the selling checkbox is show the selling options
  $("[name='selling']").click(function () {
    if (this.checked) {
      $(".cuk-selling-options").addClass("cuk-selected");
      $(".cuk-selling-options").removeClass("cuk-unselected");
    } else {
      $(".cuk-selling-options").removeClass("cuk-selected");
      $(".cuk-selling-options").addClass("cuk-unselected");
      $("[name='SaleTenure']").prop("checked", false); // Reset if freehold/leasehold had been selected
      $("[name='salePrice']").val(""); // Reset sale price
    }
  });

  $("[name='SaleTenure']").change(function () {
    $(".cuk-saleprice-input").addClass("cuk-show");
  });

  // Purchase/sale prices set to 0 initially
  let purchasePrice = 0;
  let salePrice = 0;

  // Get purchase price
  $("#purchasePrice").on("change", function () {
    purchasePrice = parseFloat($(this).val());

    // Since this is he last logical step we can enable the "get quote" button
    $("#cuk-get-quote").removeClass("cuk-btn--disabled");

    // Populate the results tables
    populateResultsFields();
  });

  // Get sale price
  $("#salePrice").on("change", function () {
    salePrice = parseFloat($(this).val());

    // Since this is he last logical step we can enable the "get quote" button
    $("#cuk-get-quote").removeClass("cuk-btn--disabled");

    // Populate the results tables
    populateResultsFields();
  });

  // Expenses
  let freeholdSaleTitleAndPlanCopy = parseFloat(
    $("[name='cuk_freehold_sale_title_and_plan_copy']").val()
  );
  let freeholdSaleDocumentsCopy = parseFloat(
    $("[name='cuk_freehold_sale_documents_copy']").val()
  );
  let leaseholdSaleTitleAndPlanCopy = parseFloat(
    $("[name='cuk_leasehold_sale_title_and_plan_copy']").val()
  );
  let leaseholdFreeholdSaleTitleAndPlanCopy = parseFloat(
    $("[name='cuk_leasehold_sale_freehold_title_and_plan_copy']").val()
  );
  let leaseholdSaleDocumentsCopy = parseFloat(
    $("[name='cuk_leasehold_sale_documents_copy']").val()
  );
  let leaseholdSaleManagingAgentsFees = parseFloat(
    $("[name='cuk_leasehold_sale_managing_agents_fees']").val()
  );
  let freeholdPurchaseSearchesAndVAT = parseFloat(
    $("[name='cuk_freehold_purchase_searches_and_vat']").val()
  );
  let freeholdPurchaseLandRegFee = parseFloat(
    $("[name='cuk_freehold_purchase_land_reg_fee']").val()
  );
  let freeholdPurchaseBankruptcy = parseFloat(
    $("[name='cuk_freehold_purchase_bankruptcy']").val()
  );
  let leaseholdPurchaseSearchesAndVAT = parseFloat(
    $("[name='cuk_leasehold_purchase_searches_and_vat']").val()
  );
  let leaseholdPurchaseLandRegFee = parseFloat(
    $("[name='cuk_leasehold_purchase_land_reg_fee']").val()
  );
  let leaseholdPurchaseBankruptcy = parseFloat(
    $("[name='cuk_leasehold_purchase_bankruptcy']").val()
  );
  let leaseholdPurchaseTransferNoticeCharge = parseFloat(
    $("[name='cuk_leasehold_purchase_transfer_notice_charge']").val()
  );

  // Fees
  let samedayBankTransfer = parseFloat(
    $("[name='cuk_sameday_bank_transfer']").val()
  );
  let fileStorageFee = parseFloat($("[name='cuk_filestorage_fee']").val());
  let freeholdStartPrice = parseFloat(
    $("[name='cuk_legal_freeholdstartPrice']").val()
  );
  let leaseholdStartPrice = parseFloat(
    $("[name='cuk_legal_leaseholdstartPrice']").val()
  );
  let freeholdBasicFee = parseFloat(
    $("[name='cuk_legal_freeholdBasicFee']").val()
  );
  let leaseholdBasicFee = parseFloat(
    $("[name='cuk_legal_leaseholdBasicFee']").val()
  );
  let freeholdPriceIncrease = parseFloat(
    $("[name='cuk_legal_freeholdpriceIncrease']").val()
  );
  let leaseholdPriceIncrease = parseFloat(
    $("[name='cuk_legal_leaseholdpriceIncrease']").val()
  );
  let freeholdFeeIncrease = parseFloat(
    $("[name='cuk_legal_freeholdfeeIncrease']").val()
  );
  let leaseholdFeeIncrease = parseFloat(
    $("[name='cuk_legal_leaseholdfeeIncrease']").val()
  );

  // Populate results fields
  function populateResultsFields() {
    /** These 2 apply to all the results tables */
    $(".cuk-same-day-bank-transfer").text(CUKToFixed(samedayBankTransfer));
    $(".cuk-file-storage-fee").text(CUKToFixed(fileStorageFee));

    /** Freehold purchase */
    let freeholdPurchaseLegalFees = calculateFreeholdLegalFees(purchasePrice);
    let freeholdPurchaseVAT =
      (freeholdPurchaseLegalFees + samedayBankTransfer + fileStorageFee) * 0.2;
    let freeholdPurchaseLRRF =
      calculateLandRegistryRegistrationFees(purchasePrice);
    let freeholdPurchaseSDLT = 0;
    if (selectedSDLT === "sdlt") {
      freeholdPurchaseSDLT = calculateStandard_SDLT(purchasePrice);
    } else if (selectedSDLT === "sdltftb") {
      freeholdPurchaseSDLT = calculateFTB_SDLT(purchasePrice);
    } else {
      freeholdPurchaseSDLT = calculateHR_SDLT(purchasePrice);
    }

    let freeholdPurchaseExpenses =
      freeholdPurchaseSearchesAndVAT +
      freeholdPurchaseSDLT +
      freeholdPurchaseLRRF +
      freeholdPurchaseLandRegFee +
      freeholdPurchaseBankruptcy;
    let freeholdPurchaseFees =
      freeholdPurchaseLegalFees +
      samedayBankTransfer +
      fileStorageFee +
      freeholdPurchaseVAT;

    $(".cuk-freehold-purchase-searches-and-vat").text(
      CUKToFixed(freeholdPurchaseSearchesAndVAT)
    );
    $(".cuk-freehold-purchase-sdlt").text(CUKToFixed(freeholdPurchaseSDLT)); // Calculate the SDLT
    $(".cuk-freehold-purchase-lrrf").text(CUKToFixed(freeholdPurchaseLRRF)); // Calculate LRRF
    $(".cuk-freehold-purchase-lrsf").text(
      CUKToFixed(freeholdPurchaseLandRegFee)
    );
    $(".cuk-freehold-purchase-bankruptcy-fee").text(
      CUKToFixed(freeholdPurchaseBankruptcy)
    );
    $(".cuk-freehold-purchase-expenses-total").text(
      CUKToFixed(freeholdPurchaseExpenses)
    );
    $(".cuk-freehold-purchase-legal").text(
      CUKToFixed(freeholdPurchaseLegalFees)
    );
    $(".cuk-freehold-purchase-vat").text(CUKToFixed(freeholdPurchaseVAT));
    $(".cuk-freehold-purchase-total-fees").text(
      CUKToFixed(freeholdPurchaseFees)
    );
    $(".cuk-freehold-purchase-grandtotal").text(
      CUKToFixed(freeholdPurchaseExpenses + freeholdPurchaseFees)
    );

    tables[0].title =
      "Freehold purchase property of £" + CUKToFixedNumber(purchasePrice);
    tables[0].fields["Searches and VAT (approx)*"] = CUKToFixed(
      freeholdPurchaseSearchesAndVAT
    );
    tables[0].fields["Stamp Duty Land Tax ( Standard SDLT )"] =
      CUKToFixed(freeholdPurchaseSDLT);
    tables[0].fields["Land Registry Registration Fee"] =
      CUKToFixed(freeholdPurchaseLRRF);
    tables[0].fields["Land Registry Search Fee"] = CUKToFixed(
      freeholdPurchaseLandRegFee
    );
    tables[0].fields["Land Charges (Bankruptcy) Search Fee (per name)"] =
      CUKToFixed(freeholdPurchaseBankruptcy);
    tables[0].fields["Expenses total"] = CUKToFixed(freeholdPurchaseExpenses);
    tables[0].fields["Legal fees"] = CUKToFixed(freeholdPurchaseLegalFees);
    tables[0].fields["Fee for each same day bank transfer"] =
      CUKToFixed(samedayBankTransfer);
    tables[0].fields["File storage fee"] = CUKToFixed(fileStorageFee);
    tables[0].fields["VAT at 20.0%"] = CUKToFixed(freeholdPurchaseVAT);
    tables[0].fields["Fees total"] = CUKToFixed(freeholdPurchaseFees);
    tables[0].fields["Grand Total"] = CUKToFixed(
      freeholdPurchaseExpenses + freeholdPurchaseFees
    );

    /** Leasehold purchase */
    let leaseholdPurchaseLegalFees = calculateLeaseholdLegalFees(purchasePrice);
    let leaseholdPurchaseVAT =
      (leaseholdPurchaseLegalFees + samedayBankTransfer + fileStorageFee) * 0.2;
    let leaseholdPurchaseLRRF =
      calculateLandRegistryRegistrationFees(purchasePrice);
    let leaseholdPurchaseSDLT = 0;
    if (selectedSDLT === "sdlt") {
      leaseholdPurchaseSDLT = calculateStandard_SDLT(purchasePrice);
    } else if (selectedSDLT === "sdltftb") {
      leaseholdPurchaseSDLT = calculateFTB_SDLT(purchasePrice);
    } else {
      leaseholdPurchaseSDLT = calculateHR_SDLT(purchasePrice);
    }

    let leaseholdPurchaseExpenses =
      leaseholdPurchaseSearchesAndVAT +
      leaseholdPurchaseSDLT +
      leaseholdPurchaseLRRF +
      leaseholdPurchaseTransferNoticeCharge +
      leaseholdPurchaseLandRegFee +
      leaseholdPurchaseBankruptcy;
    let leaseholdPurchaseFees =
      leaseholdPurchaseLegalFees +
      samedayBankTransfer +
      fileStorageFee +
      leaseholdPurchaseVAT;

    $(".cuk-leasehold-purchase-searches-and-vat").text(
      CUKToFixed(leaseholdPurchaseSearchesAndVAT)
    );
    $(".cuk-leasehold-purchase-sdlt").text(CUKToFixed(leaseholdPurchaseSDLT)); // Calculate the SDLT
    $(".cuk-leasehold-purchase-lrrf").text(CUKToFixed(leaseholdPurchaseLRRF)); // Calculate LRRF
    $(".cuk-leasehold-purchase-transfer-notice-charge").text(
      CUKToFixed(leaseholdPurchaseTransferNoticeCharge)
    );
    $(".cuk-leasehold-purchase-lrsf").text(
      CUKToFixed(leaseholdPurchaseLandRegFee)
    );
    $(".cuk-leasehold-purchase-bankruptcy-fee").text(
      CUKToFixed(leaseholdPurchaseBankruptcy)
    );
    $(".cuk-leasehold-purchase-expenses-total").text(
      CUKToFixed(leaseholdPurchaseExpenses)
    );
    $(".cuk-leasehold-purchase-legal").text(
      CUKToFixed(leaseholdPurchaseLegalFees)
    );
    $(".cuk-leasehold-purchase-vat").text(CUKToFixed(leaseholdPurchaseVAT));
    $(".cuk-leasehold-purchase-total-fees").text(
      CUKToFixed(leaseholdPurchaseFees)
    );
    $(".cuk-leasehold-purchase-grandtotal").text(
      CUKToFixed(leaseholdPurchaseExpenses + leaseholdPurchaseFees)
    );

    tables[2].title =
      "Leasehold purchase property of £" + CUKToFixedNumber(purchasePrice);
    tables[2].fields["Searches and VAT (approx)*"] = CUKToFixed(
      leaseholdPurchaseSearchesAndVAT
    );
    tables[2].fields["Stamp Duty Land Tax ( Standard SDLT )"] = CUKToFixed(
      leaseholdPurchaseSDLT
    );
    tables[2].fields["Land Registry Registration Fee"] = CUKToFixed(
      leaseholdPurchaseLRRF
    );
    tables[2].fields[
      "Notice to Freeholder/Landlord of Transfer & Charge (approximate)"
    ] = CUKToFixed(leaseholdPurchaseTransferNoticeCharge);
    tables[2].fields["Land Registry Search Fee"] = CUKToFixed(
      leaseholdPurchaseLandRegFee
    );
    tables[2].fields["Land Charges (Bankruptcy) Search Fee (per name)"] =
      CUKToFixed(leaseholdPurchaseBankruptcy);
    tables[2].fields["Expenses total"] = CUKToFixed(leaseholdPurchaseExpenses);
    tables[2].fields["Legal fees"] = CUKToFixed(leaseholdPurchaseLegalFees);
    tables[2].fields["Fee for each same day bank transfer"] =
      CUKToFixed(samedayBankTransfer);
    tables[2].fields["File storage fee"] = CUKToFixed(fileStorageFee);
    tables[2].fields["VAT at 20.0%"] = CUKToFixed(leaseholdPurchaseVAT);
    tables[2].fields["Fees total"] = CUKToFixed(leaseholdPurchaseFees);
    tables[2].fields["Grand Total"] = CUKToFixed(
      leaseholdPurchaseExpenses + leaseholdPurchaseFees
    );

    /** Freehold sale */
    let freeholdSaleLegalFees = calculateFreeholdLegalFees(salePrice);
    let freeholdSaleVAT =
      (freeholdSaleLegalFees + samedayBankTransfer + fileStorageFee) * 0.2;
    let freeholdSaleExpenses =
      freeholdSaleTitleAndPlanCopy + freeholdSaleDocumentsCopy;
    let freeholdSaleFees =
      freeholdSaleLegalFees +
      samedayBankTransfer +
      fileStorageFee +
      freeholdSaleVAT;

    $(".cuk-freehold-sale-title-and-plan-copy").text(
      CUKToFixed(freeholdSaleTitleAndPlanCopy)
    );
    $(".cuk-freehold-sale-documents-copy").text(
      CUKToFixed(freeholdSaleDocumentsCopy)
    );
    $(".cuk-freehold-sale-expenses-total").text(
      CUKToFixed(freeholdSaleExpenses)
    );
    $(".cuk-freehold-sale-legal").text(CUKToFixed(freeholdSaleLegalFees));
    $(".cuk-freehold-sale-vat").text(CUKToFixed(freeholdSaleVAT));
    $(".cuk-freehold-sale-total-fees").text(CUKToFixed(freeholdSaleFees));
    $(".cuk-freehold-sale-grandtotal").text(
      CUKToFixed(freeholdSaleExpenses + freeholdSaleFees)
    );

    tables[1].title =
      "Freehold sale property of £" + CUKToFixedNumber(salePrice);
    tables[1].fields["Official Copy of title and plan"] = CUKToFixed(
      freeholdSaleTitleAndPlanCopy
    );
    tables[1].fields["Official Copy Documents (if necessary)"] = CUKToFixed(
      freeholdSaleDocumentsCopy
    );
    tables[1].fields["Expenses total"] = CUKToFixed(freeholdSaleExpenses);
    tables[1].fields["Legal fees"] = CUKToFixed(freeholdSaleLegalFees);
    tables[1].fields["Fee for each same day bank transfer"] =
      CUKToFixed(samedayBankTransfer);
    tables[1].fields["File storage fee"] = CUKToFixed(fileStorageFee);
    tables[1].fields["VAT at 20.0%"] = CUKToFixed(freeholdSaleVAT);
    tables[1].fields["Fees total"] = CUKToFixed(freeholdSaleFees);
    tables[1].fields["Grand Total"] = CUKToFixed(
      freeholdSaleExpenses + freeholdSaleFees
    );

    /** Leasehold sale */
    let leaseholdSaleLegalFees = calculateLeaseholdLegalFees(salePrice);
    let leaseholdSaleVAT =
      (leaseholdSaleLegalFees + samedayBankTransfer + fileStorageFee) * 0.2;
    let leaseholdSaleExpenses =
      leaseholdSaleTitleAndPlanCopy +
      leaseholdFreeholdSaleTitleAndPlanCopy +
      leaseholdSaleDocumentsCopy +
      leaseholdSaleManagingAgentsFees;
    let leaseholdSaleFees =
      leaseholdSaleLegalFees +
      samedayBankTransfer +
      fileStorageFee +
      leaseholdSaleVAT;

    $(".cuk-leasehold-sale-title-and-plan-copy").text(
      CUKToFixed(leaseholdSaleTitleAndPlanCopy)
    );
    $(".cuk-leasehold-freehold-sale-title-and-plan-copy").text(
      CUKToFixed(leaseholdFreeholdSaleTitleAndPlanCopy)
    );
    $(".cuk-leasehold-sale-documents-copy").text(
      CUKToFixed(leaseholdSaleDocumentsCopy)
    );
    $(".cuk-leasehold-sale-managing-agents-fees").text(
      CUKToFixed(leaseholdSaleManagingAgentsFees)
    );
    $(".cuk-leasehold-sale-expenses-total").text(
      CUKToFixed(leaseholdSaleExpenses)
    );
    $(".cuk-leasehold-sale-legal").text(CUKToFixed(leaseholdSaleLegalFees));
    $(".cuk-leasehold-sale-vat").text(CUKToFixed(leaseholdSaleVAT));
    $(".cuk-leasehold-sale-total-fees").text(CUKToFixed(leaseholdSaleFees));
    $(".cuk-leasehold-sale-grandtotal").text(
      CUKToFixed(leaseholdSaleExpenses + leaseholdSaleFees)
    );

    tables[3].title =
      "Leasehold sale property of £" + CUKToFixedNumber(salePrice);
    tables[3].fields["Official Copy of title and plan (leasehold)"] =
      CUKToFixed(leaseholdSaleTitleAndPlanCopy);
    tables[3].fields["Official Copy of title and plan (freehold)"] = CUKToFixed(
      leaseholdFreeholdSaleTitleAndPlanCopy
    );
    tables[3].fields["Official Copy Documents"] = CUKToFixed(
      leaseholdSaleDocumentsCopy
    );
    tables[3].fields[
      "Managing Agent's Fees (replies to enquiries) (inc. VAT) (approx.)"
    ] = CUKToFixed(leaseholdSaleManagingAgentsFees);
    tables[3].fields["Expenses total"] = CUKToFixed(leaseholdSaleExpenses);
    tables[3].fields["Legal fees"] = CUKToFixed(leaseholdSaleLegalFees);
    tables[3].fields["Fee for each same day bank transfer"] =
      CUKToFixed(samedayBankTransfer);
    tables[3].fields["File storage fee"] = CUKToFixed(fileStorageFee);
    tables[3].fields["VAT at 20.0%"] = CUKToFixed(leaseholdSaleVAT);
    tables[3].fields["Fees total"] = CUKToFixed(leaseholdSaleFees);
    tables[3].fields["Grand Total"] = CUKToFixed(
      leaseholdSaleExpenses + leaseholdSaleFees
    );
  }

  populateResultsFields();

  // Functions to calculate legal fees based on property type ie: freehold or leasehold
  // @ Arithmetic formula: basicFee + Math.ceil((price - startPrice) / priceIncrease) * feeIncrease
  // These values come from <input type="hidden"> in index.html - Their values will be populated from the backend
  function calculateFreeholdLegalFees(price) {
    return (
      freeholdBasicFee +
      Math.ceil((price - freeholdStartPrice) / freeholdPriceIncrease) *
        freeholdFeeIncrease
    );
  }

  function calculateLeaseholdLegalFees(price) {
    return (
      leaseholdBasicFee +
      Math.ceil((price - leaseholdStartPrice) / leaseholdPriceIncrease) *
        leaseholdFeeIncrease
    );
  }

  //============= NEW CALCULATIONS AS OF SEPTEMBER 2022 ==================== //
  // Function to calculate STANDARD Stamp Duty Land Tax (SDLT)
  // @params: property-price
  // @return: the calculated SDLT
  function calculateStandard_SDLT(price) {
    let sdlt;
    if (price <= 250000) {
      sdlt = 0; // 0%
    } else if (price >= 250000.01 && price <= 925000) {
      sdlt = (price - 250000) * 0.05; // 5%
    } else if (price >= 925000.01 && price <= 1500000) {
      sdlt = (price - 925000) * 0.1; // 10%

      sdlt += 675000 * 0.05; // (5% - the portion from £250,000 to £925,000)
    } else if (price > 1500000.01) {
      sdlt = (price - 1500000) * 0.12; // 12%

      sdlt += 675000 * 0.05; // (5% - the portion from £250,000 to £925,000)
      sdlt += 575000 * 0.1;  // (10% - the portion from £925,000 to £1,500,000)
    }

    return sdlt;
  }

  // Function to calculate FIRST-TIME BUYER Stamp Duty Land Tax (sdltFTB)
  // @params: property-price
  // @return: the calculated sdltFTB
  function calculateFTB_SDLT(price) {
    let ftb_sdlt;
    if (price <= 425000) {
      ftb_sdlt = 0; // 0%
    } else if (price >= 425000.01 && price <= 625000.0) {
      ftb_sdlt = (price - 425000) * 0.05; // 5%
    } else {
      // Price is over 625000
      alert(
        "You cannot claim the relief. Please select Standard or Higher-Rate SDLT option"
      );
      $("[name='sdltRate']").prop("checked", false);
      return 0;
    }

    return ftb_sdlt;
  }

  // Function to calculate HIGHER-RATE Stamp Duty Land Tax (sdltHR)
  // @params: property-price
  // @return: the calculated sdltHR
  function calculateHR_SDLT(price) {
    let hr_sdlt = 0;
    if (price <= 250000) {
      hr_sdlt = price * 0.03; // 3%
    } else if (price >= 250000.01 && price <= 925000.0) {
      hr_sdlt = (price - 250000) * 0.08; // 8%

      hr_sdlt += 250000 * 0.03; // 3% - The portion under 250,000
    } else if (price >= 925000.01 && price <= 1500000.0) {
      hr_sdlt = (price - 925000) * 0.13; // 13%

      hr_sdlt += 250000 * 0.03; // 3% - The portion under 250,000
      hr_sdlt += 675000 * 0.08; // 8% - The portion from 250,000.01 to 925,000.00
    } else {
      // Price exceeds 1,500, 000
      hr_sdlt = (price - 1500000) * 0.15; // 15%

      hr_sdlt += 250000 * 0.03; // 3% - The portion under 250,000
      hr_sdlt += 675000 * 0.08; // 8% - The portion from 250,000.01 to 925,000.00
      hr_sdlt += 575000 * 0.13; // 13% - The portion from 925,000.01 to 1,500,000.00
    }

    return hr_sdlt;
  }

  // Function to calculate Land registry registratuon fee (LRRF)
  // @params: property-price
  // @return: the calculated LRRF
  function calculateLandRegistryRegistrationFees(price) {
    let lrrf;

    if (price <= 80000.0) {
      lrrf = 20;
    } else if (price >= 80000.01 && price <= 100000.0) {
      lrrf = 40;
    } else if (price >= 100000.01 && price <= 200000.0) {
      lrrf = 95;
    } else if (price >= 200000.01 && price <= 500000.0) {
      lrrf = 135;
    } else if (price >= 500000.01 && price <= 1000000.0) {
      lrrf = 270;
    } else if (price >= 1000000.0) {
      lrrf = 455;
    }

    return lrrf;
  }

  // Get quote
  $("#CUK-calculator-form").on("submit", function (e) {
    e.preventDefault(); // Prevent form submission

    // Reset the results in case we had already populated them
    resetResultsFields();

    // Check if all the possible checks have been clicked
    if (!checkSelectedOptions()) {
      return;
    } else {
      $(this).removeClass("cuk-btn--disabled");
    }

    // If buying has been selected then show the "Searches and VAT" text block
    if ($("[name='buying']").is(":checked")) {
      console.log("checkd");
      $(".cuk-searches-and-vat-approx").addClass("show");
    } else {
      $(".cuk-searches-and-vat-approx").removeClass("show");
    }

    // Determine how many tables are to be displayed
    // If only one table then stretch it across the screen
    if (
      $("[name='purchaseTenure']").is(":checked") &&
      $("[name='SaleTenure']").is(":checked")
    ) {
      $(".cuk-display-results-grid").removeClass("cuk-stretch-table");
    } else {
      $(".cuk-display-results-grid").addClass("cuk-stretch-table");
    }

    // Determine which purchase results table to show
    if ($("[name='purchaseTenure']").is(":checked")) {
      if (
        $("[name='purchaseTenure']:checked").val().toLowerCase() ===
        "freeholdpurchase"
      ) {
        $("#freeholdPurchaseTable").addClass("show");
        tables[0].selected = true;
      } else {
        $("#leaseholdPurchaseTable").addClass("show");
        tables[2].selected = true;
      }
    }

    // Determine which sale results table to show
    if ($("[name='SaleTenure']").is(":checked")) {
      if (
        $("[name='SaleTenure']:checked").val().toLowerCase() === "freeholdsale"
      ) {
        $("#freeholdSaleTable").addClass("show");
        tables[1].selected = true;
      } else {
        $("#leaseholdSaleTable").addClass("show");
        tables[3].selected = true;
      }
    }

    //Scroll to results
    $([document.documentElement, document.body]).animate(
      {
        scrollTop: $(".cuk-results-wrapper").offset().top,
      },
      1000
    );

    // Show email input
    $(".cuk-mail-quote").addClass("show");
    $(".cuk-caveat").addClass("show");
  });

  function checkSelectedOptions() {
    // If neither buying or selling has been selected
    if (
      !$("[name='buying']").is(":checked") &&
      !$("[name='selling']").is(":checked")
    ) {
      alert("Please select buying or selling");
      return false;
    }

    // If ONLY buying has been selected
    if (
      $("[name='buying']").is(":checked") &&
      !$("[name='selling']").is(":checked")
    ) {
      if (!$("[name='purchaseTenure']").is(":checked")) {
        alert("Please select either freehold purchase OR leasehold purchase");
        return false;
      } else {
        if (!$("[name='sdltRate']").is(":checked")) {
          alert("Please select a Standard Duty Land Tax (SDLT)");
          return false;
        }
      }

      if (
        $("[name='purchasePrice']").val() === "" ||
        $("[name='purchasePrice']").val() <= 0
      ) {
        alert("Please enter a purchase price");
        return false;
      }
    }

    // If ONLY selling has been selected
    if (
      !$("[name='buying']").is(":checked") &&
      $("[name='selling']").is(":checked")
    ) {
      if (!$("[name='SaleTenure']").is(":checked")) {
        alert("Please select either freehold sale OR leasehold sale");
        return false;
      }

      if (
        $("[name='salePrice']").val() === "" ||
        $("[name='salePrice']").val() <= 0
      ) {
        alert("Please enter a sale price");
        return false;
      }
    }

    // If both have been selected
    if (
      $("[name='buying']").is(":checked") &&
      $("[name='selling']").is(":checked")
    ) {
      if (!$("[name='purchaseTenure']").is(":checked")) {
        alert("Please select either freehold purchase OR leasehold purchase");
        return false;
      } else {
        if (!$("[name='sdltRate']").is(":checked")) {
          alert("Please select a Standard Duty Land Tax (SDLT)");
          return false;
        }
      }

      if (
        $("[name='purchasePrice']").val() === "" ||
        $("[name='purchasePrice']").val() <= 0
      ) {
        alert("Please enter a purchase price");
        return false;
      }

      if (!$("[name='SaleTenure']").is(":checked")) {
        alert("Please select either freehold sale OR leasehold sale");
        return false;
      }

      if (
        $("[name='salePrice']").val() === "" ||
        $("[name='salePrice']").val() <= 0
      ) {
        alert("Please enter a sale price");
        return false;
      }
    }

    return true;
  }

  // Reset the results fields
  function resetResultsFields() {
    // First hide all tables
    $("#freeholdSaleTable").removeClass("show");
    $("#leaseholdSaleTable").removeClass("show");
    $("#freeholdPurchaseTable").removeClass("show");
    $("#leaseholdPurchaseTable").removeClass("show");

    // Hide searches and vat approx
    $(".cuk-searches-and-vat-approx").removeClass("show");

    // Hide caveat
    $(".cuk-caveat").removeClass("show");

    // Hide email input
    $(".cuk-mail-quote").removeClass("show");

    // Reset selected tables
    tables.forEach((table, index) => {
      tables[index][Object.keys(table)[0]].selected = false;
    });
  }

  // Function to limit the number of decimals
  function CUKToFixed(value) {
    return value.toLocaleString(undefined, { minimumFractionDigits: 2 });
  }

  function CUKToFixedNumber(value) {
    return value.toLocaleString(undefined, { minimumFractionDigits: 0 });
  }

  // Mail results
  $("[name='cuk-accept-gdpr']").change(function () {
    $(this).is(":checked")
      ? $("#cuk-mail-quote").removeClass("cuk-btn--disabled")
      : $("#cuk-mail-quote").addClass("cuk-btn--disabled");
  });

  $("#cuk-mail-results").submit(function (e) {
    e.preventDefault();
    // GDPR consent
    if (!$("[name='cuk-accept-gdpr']").is(":checked")) {
      alert("Please accept the GDPR consent checkbox");
      return;
    }
    const recepient = $("#cuk-calculator-mail-results-input").val();

    $("#cuk-mail-quote").addClass("cuk-btn--pointer-disabled");
    $("#cuk-mail-quote").addClass("loading");

    let selectedTables = [];
    tables.forEach((table, index) => {
      if (tables[index].selected) {
        selectedTables.push(table); // Whichever table has been selected is pushed to this array
      } else {
        return;
      }
    });

    $.ajax({
      url: conveyUKAjaxObj.conveyUKAjaxURL,
      type: "POST",
      data: {
        action: "send_cuk_quote",
        security: conveyUKAjaxObj.security,
        recepient: recepient,
        selectedTables: selectedTables,
      },
      success: function (response) {
        // console.log(response);
        $("#cuk-mail-quote").removeClass("cuk-btn--pointer-disabled");
        $("#cuk-mail-quote").removeClass("loading");
        $(".cuk-mail-result").text("Email sent successfully");
        $(".cuk-mail-result").addClass("success");
      },
      error: function (error) {
        // console.log(error.responseJSON.data);
        $("#cuk-mail-quote").removeClass("cuk-btn--pointer-disabled");
        $("#cuk-mail-quote").removeClass("loading");
        $(".cuk-mail-result").text(error.responseJSON.data);
        $(".cuk-mail-result").addClass("error");
      },
    });
  });
});
